@@ -443,6 +443,11 @@ class SkillCreator(object):
 			templateFile='mypy.ini'
 		)
 
+		self.createTemplateFile(
+			outputPath=self._skillPath / 'mypy_requirements.txt',
+			templateFile='requirements.txt'
+		)
+
 		self.createTemplateFile(
 			outputPath=self._skillPath / 'sonar-project.properties',
 			templateFile='sonar-project.properties.j2',
@@ -459,11 +464,6 @@ class SkillCreator(object):
 			templateFile='tests.yml.j2'
 		)
 
-		self.createTemplateFile(
-			outputPath=Path(self._skillPath, '.github/PULL_REQUEST_TEMPLATE.md'),
-			templateFile='PULL_REQUEST_TEMPLATE.md'
-		)
-
 
 	def createInstructions(self) -> bool:
 		if not self._general['createInstructions']:
